% UAAA_DATA
% Carrega parametros e condicoes iniciais para o simulador da unidade de
% aquecimento de agua de alimentacao.

% V2021a (RPM)

%% Parametros
fprintf('## UAAA: Carregando parametros ...');

%% Parametros gerais
pAMB = 0.101325;    % pressao atmosferica (MPa)
TAMB = 20;          % temp. ambiente (C)

% Propriedades da agua
% Para calcular baixe a biblioteca IAPWS_IF97 de 
% https://www.mathworks.com/matlabcentral/fileexchange/35710-iapws_if97
%   TH2O = linspace(0.1,99.9,100)';                   % vetor de temperaturas
%   vH2O = IAPWS_IF97('v_pT',pAMB,TH2O+273.15);       % vetor de volumes esp.
%   hH2O = 1000*IAPWS_IF97('h_pT',pAMB,TH2O+273.15);  % vetor de entalpias esp.
% ou carregue as tabelas com os valores pré-calculados do arquivo:
load('uaaa_data_sw.mat')

%% Perturbacoes
tdisturb   = [0 300 330 570 600];
LAGdisturb = [15 15 25 25 15];
LAAdisturb = [20 20 70 70 20];

%% Linha de agua geral (LAG)
TLAGmin = 15;
TLAGmed = 20;
TLAGmax = 25;
pLAG    = 0.1;      % 1 bar = 0.1 MPa (relativa)

%% Linha de agua de alimentacao (LAA)
% nominal corresponde a 50 kg/s
fvLAAmin = 10e-3;
fvLAAmed = 50.3919e-3;
fvLAAmax = 100e-3;

%% Tanque de acumulacao (TAC)
% Dimensoes
diaTAC = 1.2;
perTAC = pi*diaTAC;
secTAC = pi*(diaTAC^2)/4;
altTAC = 4;
volTAC = secTAC*altTAC;

% Limites
nivTACmin = 3;
nivTACmax = 4;

% Aprox. 20W em condições nominais
% Troca termica com o ambiente
KTACAMB = 850*0.9967;
tauTACAMB = 10;

% Circulacao interna
fmAGCdes = 100;
fmAGClig = 500;

%% Tanque de alimentacao (TAL)
% Dimensoes
diaTAL = 2.5;     % (m)
perTAL = pi*diaTAL;
secTAL = pi*(diaTAL^2)/4;
altTAL = 8;       % (m)

% Limites
nivTALmin = 5;
nivTALmax = 8;

% Troca termica com o ambiente
KTALAMB = 1200;
tauTALAMB = 10;

% Circulacao interna
fmAGLdes = 40;      % (m3/s)
fmAGLlig = 200;    % (m3/s)

%% Aquecedor (AQC)
% Coeficiente de potencia (% -> W)
KAQC = 74809.9548*79.97/80;

% Dinamica do aquecedor (1a. ordem)
tauAQC = 2;

%% Bomba de circulacao (BCA)
% Coeficiente de vazao volumetrica (% -> m3/s)
KBCA = 0.00260747411984*49.97/50;

% Dinamica da velocidade (1a. ordem)
tauBCA = 10;       % (s)

%% Trocador de calor (QTR)
% O trocador de calor tem 20 elementos

% Coeficiente de troca termica (por elemento)
KQTR = 85.2530;

% Correcao de fluxo para o coeficiente de troca termica
fpctQTR = [0 5 10 20 100];
corKQTR = [0 0 0.1 0.8 1.0];

% Vazão a 100%
fmQTR100pct = 2.536128;

% Constante de tempo das paredes do tubo
tauQTR = 10;     % (s)


%% Valvula de alimentacao (VAL)
% curva da valvula (% -> Coef.Vazao)
rangeVAL  = 50;  % valor tipico para valvula globo de igual porcentagem
pctposVAL = linspace(0,100,101);
pctfvVAL  = exp( log(rangeVAL)*pctposVAL/100 )/rangeVAL;
KfvVAL    = 1.120072841;

fprintf(' ok.\n');

%% Condicoes iniciais (operacao nominal)
fprintf('## UAAA: Carregando C.I. (operacao nominal) ...');

%% Tanque de acumulacao
% Nível inicial: 3.5 m (3846.8 kg @80C)
% Elemento 1 (vizinhanca do aquecedor)
mTAC1_0 = 1000;
TTAC1_0 = 82.85;
hTAC1_0 = interp1(TH2O,hH2O,TTAC1_0,'linear','extrap');
% Elemento 2 (vizinhanca da saida de circulacao)
mTAC2_0 = 2846.8;
TTAC2_0 = 80;
hTAC2_0 = interp1(TH2O,hH2O,TTAC2_0,'linear','extrap');

% Perda de calor com o ambiente
QTACAMB_0 = 673255.5;

%% Tanque de alimentacao
% Nível inicial: 6 m (29223.3 kg @40C)
% Elemento 1 (vizinhanca do aquecedor)
mTAL1_0 = 5000;
TTAL1_0 = 46.36;
hTAL1_0 = interp1(TH2O,hH2O,TTAL1_0,'linear','extrap');
% Elemento 2 (vizinhanca da saida de circulacao)
mTAL2_0 = 24223.3;
TTAL2_0 = 40;
hTAL2_0 = interp1(TH2O,hH2O,TTAL2_0,'linear','extrap');

% Perda de calor com o ambiente
QTALAMB_0 = 1130973.4;

%% Aquecedor (AQC)
% Potencia inicial (W)
QAQCTAC_0 = 5984796.4;

%% Bomba de circulacao (BCA)
% Vazao inicial (%)
fvpctBCA_0 = 50;

%% Trocador de calor (QTR)
% O trocador tem 20 elementos

% Entalpia inicial (por elemento)
hQTR_0 = [hTAC2_0, ...
          332526.33, 330104.04, 327724.09, 325385.72 ,323088.22,...
          320830.86, 318612.98, 316433.86, 314292.84, 312189.25,...
          310122.45, 308091.79, 306096.65, 304136.40, 302210.44,...
          300318.17, 298458.99, 296632.32, 294837.50, 293073.67];

% Potencia inicial
%QQTR_0 = ones(1,20)*5311540.9/20;

%% Valvula de alimentacao (VAL)
% Abertura inicial (%)
ApctVAL_0 = 50;

fprintf(' ok.\n');
